function [dag_top order_top node_sizes_top names_top] = top_sort_dag(dag, varargin);
% rearrange the incidence matrix such that the variables appear in topological sort

% dag_top - a new incidence matrix
% order_top - the topological sort of nodes
% node_sizes_top - node sizes in topological sort
% names_top -  node names in topological sort

% optional arguments:
% 'node_sizes' - node sizes in the original sort
% 'names' - node names in the original sort

node_sizes=[]; names={};

% sort the nodes topologically
order_top = topological_sort(dag);

% rearrange the incidence matrix
N=length(order_top);
dag_top=zeros(N,N);
for row=1:N
    for col=1:N
        if dag(order_top(row),col)==1
            dag_top(row,find(order_top==col))=1;
        end
    end
end

% process the optional arguments
if nargin > 1
  args = varargin;
  nargs = length(args);
  for i=1:2:nargs
    switch args{i},
      case 'node_sizes', node_sizes = args{i+1}; 
      case 'names', names = args{i+1}; 
      otherwise,  
    	error(['invalid argument name ' args{i}]);       
    end
  end
end

if length(node_sizes)==N
    node_sizes_top=node_sizes(order_top);
end

if length(names)==N
    names_top=names(order_top);
end